package Acme::MetaSyntactic::browser;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::browser - The "browser" theme

=head1 DESCRIPTION

Some famous web browsers.

=head1 CONTRIBUTORS

Philippe "BooK" Bruhat, Sbastien Aperghis-Tramoni.

Introduced in version 0.05, published on January 16, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
mozilla netscape msie mosaic links lynx w3m opera galeon konqueror safari
camino dillo amaya arachne omniweb planetweb voyager
